Module batch

Module batch 

Batch processing: uses rayon to evaluate arrays of thousands of strings in parallel across all CPU cores.

Structs

BatchComparator
A batch comparator that evaluates many string pairs in parallel.
BatchResult
A batch comparison result.