pub struct BatchResult {
pub index_a: usize,
pub index_b: usize,
pub score: f64,
}Expand description
A batch comparison result.
Fields
index_a: usizeIndex of the first string in the input pair.
index_b: usizeIndex of the second string in the input pair.
score: f64The computed similarity score.