Module prelude

Module prelude 

Common imports for the simi crate.

Core modules should use crate::prelude::*; instead of importing individual std types.

Modules

vec
A contiguous growable array type with heap-allocated contents, written Vec<T>.

Macros

format
Creates a String using interpolation of runtime expressions.
vec
Creates a Vec containing the arguments.

Structs

Box
A pointer type that uniquely owns a heap allocation of type T.
String
A UTF-8–encoded, growable string.
Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.

Traits

ToString
A trait for converting a value to a String.